﻿using System;
using System.Collections.Generic;
using System.Globalization;
using System.Linq;
using System.Threading;
using System.Windows;
using System.Windows.Input;
using Microsoft.Practices.Prism.Events;
using Microsoft.Practices.Prism.Logging;
using Microsoft.Practices.Prism.Regions;
using Microsoft.Practices.Unity;
using Infragistics.Windows.DockManager;
using Microsoft.Practices.Prism.Commands;
using Infragistics.Windows.Controls;
using Infragistics.Windows.DataPresenter;
using System.Diagnostics;
using System.Windows.Controls;

namespace Sample
{
    public class ShellViewModel : DependencyObject, IShellViewModel
    {
        private readonly IUnityContainer container;
        private readonly IEventAggregator eventAggregator;
        private readonly IRegionManager regionManager;

        public IShellView View { get; private set; }
        public string ApplicationTitle { get; set; }
        private int idx = 0;

        #region IViewModelBase Members

        public string RegionName
        {
            get { return "shellView"; }
        }

        #endregion

        #region ICommand

        public ICommand AddView { get; set; }

        #endregion

        public ShellViewModel(IShellView view, IUnityContainer container, IRegionManager regionManager, IEventAggregator eventAggregator)
        {
            this.View = view;
            this.View.SetViewModel(this);

            this.container = container;
            this.regionManager = regionManager;
            this.eventAggregator = eventAggregator;

            this.ApplicationTitle = "Sample Application";
            this.AddView = new DelegateCommand(this.computeAddView);
        }
        

        private void computeAddView()
        {
            
            idx++;                        
            ContentPane contentPane = new ContentPane() { Header = "Pane " + idx };

            XamTabControl tabControl = new XamTabControl()  { TabStripPlacement = System.Windows.Controls.Dock.Left };
            
            TabItemEx tab1 = new TabItemEx() { Header = "tab1" };
            TabItemEx tab2 = new TabItemEx() { Header = "tab2" };
            TabItemEx tab3 = new TabItemEx() { Header = "tab3" };
            //TabItemEx tab4 = new TabItemEx() { Header = "tab4" };
            //TabItemEx tab5 = new TabItemEx() { Header = "tab5" };

            tab1.Content = this.BuildContent(1);
            tab2.Content = this.BuildContent(1);
            tab3.Content = this.BuildContent(1);
            //tab4.Content = this.BuildContent(4);
            //tab5.Content = this.BuildContent(5);
            
            tabControl.Items.Add(tab1);
            tabControl.Items.Add(tab2);
            tabControl.Items.Add(tab3);
            //tabControl.Items.Add(tab4);
            //tabControl.Items.Add(tab5);

            contentPane.Content = tabControl;

            this.View.TabGpPane.Items.Add(contentPane);
            this.View.TabGpPane.SelectedItem = contentPane;
                       
        }

        private Grid BuildContent(int nbGrid)
        {
            Random r = new Random();
            Grid g = new Grid();

            ISampleGridViewModel viewModel = null;
            UserControl view = null;

            for (int i = 0; i < nbGrid; i++)
            {
                //IOC PRISM
                //we passe the number of row to be generate
                viewModel = this.container.Resolve<ISampleGridViewModel>(
                 new ParameterOverride("row", r.Next(1, 20))
                 );

                view = viewModel.View as UserControl;

                g.RowDefinitions.Add(new RowDefinition());
                Grid.SetRow(view, i);
                g.Children.Add(view);
            }
            
            return g;
        }
        
    }
}
